#
# spec file for package webcamoid
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           webcamoid
Version:        9.2.3
Release:        2.3
Summary:        Webcam applet for Plasma
License:        GPL-3.0-or-later
Group:          System/GUI/KDE
URL:            https://webcamoid.github.io/
Source:         https://github.com/hipersayanX/Webcamoid/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM webcamoid-disable_autoupdate.patch
Patch0:         webcamoid-disable_autoupdate.patch
BuildRequires:  bison
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  flex
%if 0%{?suse_version} > 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc13-c++
%endif
BuildRequires:  glibc-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  perl-Text-Markdown
BuildRequires:  pkgconfig
BuildRequires:  qt6-tools-linguist
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Multimedia)
BuildRequires:  cmake(Qt6Quick)
BuildRequires:  cmake(Qt6QuickControls2)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libspa-0.2)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(libvlc)
BuildRequires:  pkgconfig(vlc-plugin)
Provides:       plasmoid-webcamoid = %{version}
Obsoletes:      plasmoid-webcamoid < %{version}

%description
Webcam applet for Plasma.

Features:
* Take pictures with the webcam.
* Record videos.
* Manages multiple webcams.
* Play/Stop capture, this saves resources while the applet is not in use.
* Written in C++.
* Qt based software.
* Custom controls for each webcam.
* Popup applet support (you can embed Webcamoid in the panel).
* +50 video effects available.
* Effects with live previews.
* Translated to many languages.
* Stand alone installation mode (use it as a normal program).
* Use custom network and local files as capture devices.
* Capture from desktop.

%prep
%autosetup -p1

%build
export CXX=g++
test -x "$(type -p g++-13)" && export CXX=g++-13
%cmake_qt6 \
 -DPLUGINSDIR=%{_qt6_pluginsdir} \
 -DOUTPUT_QT_PLUGINS_DIR=%{_qt6_pluginsdir} \
 -DNOCHECKUPDATES=TRUE
%qt6_build

# generate help file
Markdown.pl --html4 README.md > README.html

%install
%qt6_install

rm %{buildroot}%{_libdir}/libavkys.so

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc AUTHORS ChangeLog README.html THANKS
%license COPYING
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/metainfo/io.github.%{name}.Webcamoid.metainfo.xml
%{_datadir}/icons/hicolor
%{_libdir}/libavkys.so.*
%{_mandir}/man1/%{name}.1%{ext_man}
%{_qt6_pluginsdir}/avkys

%changelog
* Wed Nov 13 2024 Luigi Baldoni <aloisio@gmx.com>
- Add webcamoid-disable_autoupdate.patch (fixes boo#1196225)
* Thu Oct  3 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 9.2.3
  * Misc non-linux changes
  version 9.2.0:
  * Webcamoid ported to Qt6.
  * Added PipeWire video capture support.
  * Added Xlib screen capture plugin.
  * Added desktop capture using FFmpeg.
  * Added option to show or hide the mouse cursor on screen
    capture.
  * Qt screen capture plugin is now using QScreenCapture.
  * Added ColorKey plugin.
  * Added support for extended controls in V4L2.
  * Attend to screen orientation.
  * Fixed ARM 64 packages.
  * Fixed saving the selected camera format.
  * Added a debug log to the preferences dialog.
  * Added options for enabling/disabling interprocess
    optimizations.
  * Do not show the video outputs if the virtual camera is not
    supported.
* Thu Jun 15 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 9.1.1
  * Removed Qml import line that prevented UI to load.
  * Using common AppID for all platforms.
- Add Qt5Multimedia build requirement
* Sun Jun 11 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 9.1.0
  * Redesigned UI to work in smaler screens.
  * Now providing ARM packages for GNU/Linux.
  * Allow using an image file as video source.
  * Full support for screen readers and keyboard navigation.
  * Added image capture to clipboard.
  * Added PortAudio and SDL as alternative audio device plugins.
  * Added QCamera as alternative camera capture plugin.
  * Added FFmpeg screen capture support.
  * The virtual camera from GNU/Linux can also be installed in
    non x86 platforms.
  * video synchronization can be enebled/disabled on playback.
  * New video Effects: AnalogTV, Zoom, Crop, Opacity.
  * Removed Scale and Scroll video effects.
  * PrimariesColors plugin renamed to Saturated.
  * Improved virtual camera detection. Webcamoid will only offer
    akvcam or AkVirtualCamera in the only case no other virtual
    camera was installed, or in the case it was manually selected.
  * Allow positioning Webcamoid widow on any screen.
  * Added uninstall target in cmake build to aid development
    cycles.
  * Fixed virtual camera install in GNU/Linux.
  * Translation files are not embeded in the binary, more
    translations can be added and tested without recompiling.
  * Fixed ALSA deices reading.
  * Properly save enabled and disabled plugins.
- Drop webcamoid-manpath.patch and webcamoid-ffmpeg5.patch
  (merged upstream)
* Fri May 19 2023 Dave Plater <davejplater@gmail.com>
- Build with ffmpeg-4 to fix factory build
* Tue Aug 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add FFmpeg 5 compatibility change:
  * webcamoid-ffmpeg5.patch
- Remove obsolete packaging macros
* Tue Feb 15 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 9.0.0
  * Now Qt 5.15 is the minimum required version.
  * More modern UI redesign.
  * Now the default theme can adapt to the current color scheme
    of the system.
  * Switched build system to CMake.
  * Redesigned plugins system to a more expandable one.
  * Photos and videos are saved in their default folders, and
    its also user customizable.
  * You can now open the last photo taken and the last video
    recorded from Webcamoid.
  * Added support for screen capturing in PipeWire/Wayland.
  * Added VLC as video playback backend.
  * The virtual camera is now fully customizable (format,
    resolution, default picture, etc.).
  * Improved error messages for the virtual camera.
  * Add face tracking plugin.
  * Add appstream data.
  * Fixed privilege escalation when creating the virtual camera.
  * Added support for background image replacement in FaceDetect
    plugin.
  * Fixed default masks rendering when selecting an image from
    file system.
  * Added more options to the FaceDetect plugin.
  * Added support for FFmpeg 5.0.
  * Fixed video recording with FFmpeg.
  * Added Otsu threshold, and other video effects plugins.
  * Improved FalseColor plugin UI.
  * Optimized Charify plugin.
  * Added donations links for people who wants to support the
    project.
- Drop webcamoid-gcc11.patch (no longer useful)
- Add webcamoid-manpath.patch
- Drop devel subpackage
- Link against pipewire, spa, libusb and vlc
* Fri Jun  4 2021 Luigi Baldoni <aloisio@gmx.com>
- Add webcamoid-gcc11.patch to fix build in Factory
* Tue Feb 16 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 8.8.0
  * Added option for blurring outside detected face in
    FaceDetect plugin
  * Added public method for detecteding face rectangles in
    FaceDetect plugin
  * Fixed some minor bugs when capturing from camera.
* Sat Mar 28 2020 Bogdano Arendartchuk <BArendartchuk@suse.com>
- require libqt5-qtquickcontrols and libqt5-qtquickcontrols2
* Tue Oct 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 8.7.1
  * Load virtual camera default frame from file instead of
    resources.
* Tue Oct  1 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 8.7.0
  * Removed unnecessary Bin and Probe plugins.
  * Added audio latency control.
  * Removed OSS and QtAudio submodules.
  * Fixed a bug that happened when changing the format, resolution
    or FPS of the camera (commit 41448aa).
  * Improved error messages for the virtual camera (issue #187).
  * Fixed segfaults.
* Tue Mar 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 8.6.1
  * AppImage now properly show the icon (issue #94).
  * Use correct subdir for manpage (issue #170, thanks Luigi
    Baldoni!).
- Dropped webcamoid-mandir.patch (merged upstream)
* Mon Mar 25 2019 Christophe Giboudeaux <christophe@krop.fr>
- Drop the qimageblitz dependency. Unused since 5.0.0.
- Drop the Frei0r dependency. Unused since 5.1.0.
- Fix the old description 'KDE' is the community, 'plasmoid' is no longer used.
- Ensure neutrality of description.
* Tue Mar  5 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 8.6.0
  * Now webcam settings are saved.
  * Enabled secondary plugins, and fixed segfaults and  memleaks
    in GStreamer.
  * Fixed segfaults and memory leaks in MacOS.
  * Fixed GIF playback in FFmpeg.
  * Build now support MSYS2.
  * Added static analysis with Codacy.
  * Fixed manpage install.
  * Install paths now follow Qt install paths structure.
- Added webcamoid-mandir.patch
* Tue Jan 22 2019 aloisio@gmx.com
- Update to version 8.5.0
  * UI ported to QtQuick Controls 2.
  * Reworked virtual camera for GNU/Linux, Mac and Windows.
  * Qt 5.9.0 as minimum requirement.
  * Faster build and smaller binaries.
  * Added build info.
  * Fixed crash and many other bugs in FreeBSD.
  * Added support for Microsoft Media Foundation capture.
  * Fixed shadow build.
  * Added support for FFmpeg 4.0.
  * Fixed bug when reading/setting webcam controls.
  * Added support for akvcam, default in-house virtual camera
    solution for GNU/Linux.
  * Fixed rendering problems in Mac.
  * Added support for FreeBSD in deploy scripts.
  * Fixed many bugs when recording audio and video.
  * Default recording video bitrate is now 1.5Mbps.
  * Fixed audio support in Windows.
  * Removed 'su' and 'sudo' as root method when installing the
    virtual camera in GNU/Linux.
  * Removed Syphon support for Mac.
  * Improved translations.
- Dropped webcamoid-8.1.0-ffmpeg4.patch (no longer necessary)
* Sun Jul  8 2018 aloisio@gmx.com
- Added webcamoid-8.1.0-ffmpeg4.patch to support ffmpeg4 and
  changed requirements accordingly
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Wed Dec 13 2017 aloisio@gmx.com
- Added frei0r-plugins-opencv as runtime requirement to account
  for (boo#1068792)
* Tue Oct 10 2017 aloisio@gmx.com
- Update to version 8.1.0
  * Improved startup time.
  * Deadlock when audio recording is enabled my be solved now.
    Audio recording enabled by default again.
  * Hopefully, fixed many segfaults in many platforms.
- Dropped webcamoid-fix_man.patch (merged upstream)
* Sat Jun 17 2017 aloisio@gmx.com
- Update to version 8.0.0
  * Added support for Mac and FreeBSD (virtual camera is not
    supported  * yet).
  * Added new masks to the FaceDetect plugin.
  * Now is possible to Switch between FFmpeg and GStreamer on
    runtime.
  * Added support for ALSA, OSS, JACK and QAudio.
  * Added support for libuvc.
  * Now is possible to select the desired input and output device,
    and  * configure playback and capture formats.
  * More translations updates.
  * Added options for configuring plugins search paths and
    blacklist  * in GUI.
  * Added options for configuring the desired frameworks and
    libraries.
  * Added formats and codecs config in recording options.
  * FFmpeg >= 3.1 required.
  * Added support for MSVC2013 and MSVC2015 build.
  * Added option for configure FPS in DesktopCapture plugin.
  * Added updates options.
  * AppImage support.
- Added webcamoid-fix_man.patch to address build problem on
  Tumbleweed
* Fri May 12 2017 aloisio@gmx.com
- Update to version 7.2.1
  * Added alternative root method (VirtualCamera). See ROOT_METHOD
    on project wiki.
  * C++11 support enabled by default.
  * Using new algorithm for Cartoon plugin.
  version 7.2.0:
  * Fixed problems when recording.
  * Added timer and flash when taking photos.
  * Better virtual camera management.
  * Added Virtual camera support for Windows.
  * Added GIF recording support (FFmpeg only).
  * Improved webcam format selection.
  * UI improvements.
  * Added play on start option.
  * Added C++11 support for Clang build.
- Renamed package to webcamoid
* Fri Apr 29 2016 aloisio@gmx.com
- Update to version 7.1.0
  * Reworked audio system.
  * Added support for compressed formats in webcams.
  * No more lags in the UI when capturing from webcam.
  * Added Windows installer.
  7.0.0:
  * Windows port finally working! EXPERIMENTAL!
  * Reworked recording options. More user friendly.
  * Removed unnecessary dependencies.
  * Many effects reworked and bugfixed.
  * Added GStreamer support, EXPERIMENTAL!
  * Fixed SEGFAULT when switching the effects.
  * Added virtual camera support (GNU/Linux only).
  * Added command line options for controlling plugins search.
  6.2.0:
  * Reworked Cartoonify plugin.
  * Some improvements in FaceDetect plugin.
  * Added Canny mode for Edge detection plugin.
  * Improved Blur and Denoise plugins.
  * Fixed QDataStream missing header.
  6.1.0:
  * Removed OpenCV as dependency (yes, again).
  * Fixed Denoise plugin SEGFAULT.
  * Translations updated.
  6.0.0:
  * New Qml UI, more user friendly.
  * Now, the effects can be customized.
  * A lot of bug fixes.
  5.1.0:
  * From now on, Webcamoid will be developed using Qt5.
  * Removed Frei0r from dependencies.
  * Added OpenCV as dependency (Face detection).
  * Removed plasmoid build since Qt5 plugins aren't compatible
    with Qt4/KDE4.
  * Now, Webcamoid can be compiled using MinGW.
  * Added webcam capture support through DirectShow.
  * There are still some patches needed to make it fully work
    in Windows.
  5.0.0:
  * Modified the effects preview for reducing resources usage.
  * Fixed stream flush on recording stop.
  * Enhanced webm video recording.
  5.0.0rc1:
  * Release Candidate version.
  * Ported to Qt5 (without the plasmoid).
  * Removed KDElibs as dependency, but still required for
    Qt4 build.
  * Removed QImageBlitz as dependency.
  * Added more effects.
  * Fixed video sync.
  * Initial port to Windows (help needed).
- Switched to Qt5
- Switched to ffmpeg 3.0
- Spec cleanup
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Mon Feb 10 2014 mailaender@opensuse.org
- Update to version 5.0.0b2
* Fri May  3 2013 fa0sck@gmail.com
- spec for openSUSE build changes:
  + Installpath all lowercase (patch)
  + Install under kde4_appsdir
  + generate help file
  + refresh translations
  + actually register plasmoid inside kde4_servicesdir
  + fix categories for desktop file
* Sun Oct 14 2012 mailaender@opensuse.org
- initial packaging
